.. Copyright 2021 Reahl Software Services (Pty) Ltd. All rights reserved.

Browser tools
-------------

.. automodule:: reahl.browsertools

Composing XPath expressions
^^^^^^^^^^^^^^^^^^^^^^^^^^^

XPath
"""""

.. autoclass:: reahl.browsertools.browsertools.XPath
   :members:

Browser interfaces
^^^^^^^^^^^^^^^^^^

DriverBrowser
"""""""""""""

.. autoclass:: reahl.browsertools.browsertools.DriverBrowser
   :members:
   :inherited-members:

Browser
"""""""

.. autoclass:: reahl.browsertools.browsertools.Browser
   :members:
   :inherited-members:

WidgetTester
""""""""""""

.. autoclass:: reahl.browsertools.browsertools.WidgetTester
   :members:
   :inherited-members:
